@@ -36,7 +36,7 @@ AreaListView::AreaListView(QWidget *parent)
 {
   QVBoxLayout *mainLayout = new QVBoxLayout(this);
   mainLayout->setSpacing(0);
-  mainLayout->setMargin(0);
+  mainLayout->setContentsMargins(0, 0, 0, 0);
 
   listView = new QTreeWidget(this);
   listView->setColumnCount(2);
@@ -58,11 +58,11 @@ AreaListView::AreaListView(QWidget *parent)
 
   QHBoxLayout *buttonsLayout = new QHBoxLayout;
   upBtn = new QPushButton;
-  upBtn->setIcon(SmallIcon("go-up"));
+  upBtn->setIcon(QIcon::fromTheme("go-up"));
   buttonsLayout->addWidget(upBtn);
 
   downBtn = new QPushButton;
-  downBtn->setIcon(SmallIcon("go-down"));
+  downBtn->setIcon(QIcon::fromTheme("go-down"));
   buttonsLayout->addWidget(downBtn);
 
   mainLayout->addLayout(buttonsLayout);
